@@ -20,6 +20,8 @@ from .main import (corpus,
                    metadata,
                    doc_id,
                    logger,
+                   logger_console,
+                   logger_fd,
 )
 
 from .search import (creator_name,
