@@ -190,7 +190,8 @@ def test_book() -> Book:
     """Return a Book for testing purposes."""
     assis_memorias = {
         'index': 'assismemorias1880',
-        'title': [ 'Memórias Póstumas de Brás Cubas', 'Epitáfio de um Pequeno Vencedor' ],
+        'title': 'Memórias Póstumas de Brás Cubas',
+        'subtitle': 'Epitáfio de um Pequeno Vencedor',
         'creator': [
             {'role': 'author',
              'name': 'Machado de Assis',
